.. _visualization.gaze_overlay:

Gaze Overlay
============

.. automodule:: eyetrace.visualization.gaze_overlay
   :members:
   :undoc-members:
   :show-inheritance:

Functions to annotate images with gaze points, pupil centers, eye landmarks,
and text overlays. These are useful for debugging or presenting results.

- :func:`draw_gaze_overlay` : draw gaze point and pupils on an image.
- :func:`draw_eye_landmarks` : draw the six landmarks of each eye.
- :func:`draw_text_overlay` : add multiple lines of text.